@@ -1553,7 +1553,6 @@ init_theme(void)
 	*/
 	style_id = gkrellm_lookup_meter_style_id(APM_STYLE_NAME);
 	assign_meter_style(style_id, "3,3,2,2", SET_BORDER, 0);
-	assign_meter_style(style_id,"small_font", SET_TEXTFONT_A, 0);
 
 	style_id = gkrellm_lookup_meter_style_id(CAL_STYLE_NAME);
 	assign_meter_style(style_id,  "small_font", SET_TEXTFONT_A, 0);
@@ -1938,7 +1937,8 @@ save_user_config(void)
 		printf(_("Cannot open config file %s for writing.\n"), config);
 		return;
 		}
-	fprintf(f, "### GKrellM user config.  Auto written, do not edit ###\n");
+	fprintf(f,
+		"### GKrellM user config.  Auto written, do not edit (usually) ###\n");
 	fprintf(f, "### Version %d.%d.%d ###\n",
 			GKRELLM_VERSION_MAJOR, GKRELLM_VERSION_MINOR, GKRELLM_VERSION_REV);
 	for (i = 0; i < sizeof(user_config) / sizeof(struct _config); ++i)
