@@ -257,12 +257,17 @@ gkrellm_apply_launcher(GtkWidget **launch_entry, GtkWidget **tooltip_entry,
 		{
 		if (launch->button == NULL)
 			{
-			if (launch->type == METER_PANEL_TYPE)
+			if (launch->type == METER_LAUNCHER)
 				launch->button = gkrellm_put_label_in_meter_button(p, func,
 										launch, launch->pad);
-			else
+			else if (launch->type == PANEL_LAUNCHER)
 				launch->button = gkrellm_put_label_in_panel_button(p, func,
 										launch, launch->pad);
+			else if (launch->type == DECAL_LAUNCHER)
+				launch->button = gkrellm_put_decal_in_meter_button(p,
+					launch->decal,
+					gkrellm_launch_button_cb, launch);
+
 			}
 		gkrellm_dup_string(&launch->command, command);
 		}
@@ -363,6 +368,29 @@ gkrellm_setup_launcher(Panel *p, Launcher *launch, gint type, gint pad)
 		}
 	}
 
+void
+gkrellm_setup_decal_launcher(Panel *p, Launcher *launch, Decal *d)
+	{
+	if (!launch)
+		return;
+	if (launch->command == NULL)
+		launch->command = g_strdup("");
+	if (launch->tooltip_comment == NULL)
+		launch->tooltip_comment = g_strdup("");
+	launch->type = DECAL_LAUNCHER;
+	launch->pad = 0;
+	launch->decal = d;
+	if (p)
+		{
+		gkrellm_configure_tooltip(p, launch);
+		if (*(launch->command) != '\0')
+			launch->button = gkrellm_put_decal_in_meter_button(p, d,
+					gkrellm_launch_button_cb, launch);
+		else
+			launch->button = NULL;	/* In case dangling pointer, see above */
+		}
+	}
+
 void
 insert_expanded_filler(GtkWidget *box)
 	{
@@ -574,14 +602,21 @@ create_about_tab(GtkWidget *vbox)
 
 #if defined(__FreeBSD__)
 	buf = g_strdup_printf(_("FreeBSD code was contributed by:\n"
-							"Hajimu UMEMOTO <ume@mahoroba.org>"));
+						"Hajimu UMEMOTO <ume@mahoroba.org>"));
 	label = gtk_label_new(buf);
 	g_free(buf);
 	gtk_box_pack_start(GTK_BOX(vbox), label, TRUE, TRUE, 0);
 #endif
 #if defined(__NetBSD__)
 	buf = g_strdup_printf(_("NetBSD code was contributed by:\n"
-							"Anthony Mallet <anthony.mallet@useless-ficus.net>"));
+						"Anthony Mallet <anthony.mallet@useless-ficus.net>"));
+	label = gtk_label_new(buf);
+	g_free(buf);
+	gtk_box_pack_start(GTK_BOX(vbox), label, TRUE, TRUE, 0);
+#endif
+#if defined(__solaris__)
+	buf = g_strdup_printf(_("Solaris code was contributed by:\n"
+						"Daisuke Yabuki <dxy@acm.org>"));
 	label = gtk_label_new(buf);
 	g_free(buf);
 	gtk_box_pack_start(GTK_BOX(vbox), label, TRUE, TRUE, 0);
@@ -1205,10 +1240,6 @@ read_theme_event(gint gkrellm_read_theme)
 		GK.theme_path = NULL;	/* Force reread of GKRELLM_THEME_CONFIG */
 		}
 	else if (GK.track_gtk_rcfiles)
-		/* This code currently not accessible (GK.track_gtk_rcfiles is not
-		|  setable) I've heard a master theme switcher (E, Gtk, xmms, gkrellm)
-		|  may be in the works which would be a better general solution.
-		*/
 		{
 		FILE	*f;
 		gchar	*gtkrc_path, *s, *g;
@@ -1219,7 +1250,7 @@ read_theme_event(gint gkrellm_read_theme)
 		gtkrc_path = g_strdup_printf("%s/.gtkrc", gkrellm_homedir());
 		if ((f = fopen(gtkrc_path, "r")) != NULL)
 			{
-				/* # -- THEME AUTO-WRITTEN DO NOT EDIT		*/
+				/* # -- THEME AUTO-WRITTEN DO NOT EDIT 	*/
 			fgets(buf, sizeof(buf), f);
 				/* include "/home/bill/.themes/XX/gtk/gtkrc	*/
 			fgets(buf, sizeof(buf), f);
