@@ -1391,7 +1391,9 @@ create_inet_monitor(GtkWidget *vbox1, InetMon *in, gint first_create)
 	GtkWidget	*vbox;
 	Chart		*cp;
 	Panel		*p;
+	Margin		*m;
 	Style		*style;
+	gint		x;
 
 	if (first_create)
 		{
@@ -1422,11 +1424,17 @@ create_inet_monitor(GtkWidget *vbox1, InetMon *in, gint first_create)
 
 	p = in->panel;
 	style = gkrellm_panel_style(style_id);
+	m = gkrellm_get_style_margins(style);
 	if (style->label_position == 50 && gkrellm_chart_width() < 80)
 		style->label_position = 40;		/* Not a kludge, an adjustment! */
 	in->list_decal = gkrellm_create_decal_pixmap(p,
 				gkrellm_decal_misc_pixmap(), gkrellm_decal_misc_mask(),
 				N_MISC_DECALS, style, -1, -1);
+	if (style->label_position <= 50)
+		x = gkrellm_chart_width() - in->list_decal->w - m->right;
+	else
+		x = m->left;
+	gkrellm_move_decal(p, in->list_decal, x, in->list_decal->y);
 
 	gkrellm_create_krell(p, gkrellm_krell_panel_image(style_id), style);
 
