@@ -1349,11 +1349,6 @@ store_net_config(gchar *name, gint enable, gint extra, gint force)
 		nc->enabled = enable;
 		nc->extra_info = extra;
 		nc->force_net_up = force;
-
-/*		nc->label = g_strdup(label);
-		nc->command = g_strdup(command);
-		nc->tooltip = g_strdup(tooltip);
-*/
 		net_config_list = g_list_append(net_config_list, nc);
 		}
 	return nc;
@@ -1598,7 +1593,9 @@ draw_totals_buttons(NetMon *net)
 	{
 	gint	frame, x, y;
 
-	if (!net->totals_shown || !net->extra_info)
+	if (   !net->totals_shown || !net->extra_info
+		|| !decal_totalA || !decal_totalB || !decal_reset
+	   )
 		return FALSE;
 	x = gkrellm_chart_width() - 2 * decal_totalA->w;
 	y = 2;
@@ -2149,6 +2146,16 @@ create_net(GtkWidget *vbox, gint first_create)
 		gtk_widget_show(timer_vbox);
 		}
 	else
+		{
+		/* Some decals don't live in a panel, they will be drawn onto
+		|  charts when needed.  So, must destroy them at create events (not
+		|  done automatically in panel lists) and then recreate them with NULL
+		|  panel and style pointers.
+		*/
+		gkrellm_destroy_decal(decal_totalA);
+		gkrellm_destroy_decal(decal_totalB);
+		gkrellm_destroy_decal(decal_reset);
+		decal_totalA = decal_totalB = decal_reset = NULL;
 		for (list = net_mon_list; list; list = list->next)
 			{
 			net = (NetMon *) list->data;
@@ -2157,14 +2164,7 @@ create_net(GtkWidget *vbox, gint first_create)
 			   )
 				create_net_monitor(NULL, net, first_create);
 			}
-	/* Some decals that don't live in a panel, they will be drawn onto
-	|  charts when needed.  So, must destroy them at create events (not done
-	|  automatically in panel lists) and then recreate them with NULL panel
-	|  and style pointers.
-	*/
-	gkrellm_destroy_decal(decal_totalA);
-	gkrellm_destroy_decal(decal_totalB);
-	gkrellm_destroy_decal(decal_reset);
+		}
 	decal_totalA = gkrellm_create_decal_pixmap(NULL,
 			gkrellm_decal_misc_pixmap(), gkrellm_decal_misc_mask(),
 			N_MISC_DECALS, NULL, 0, 0);
@@ -2361,7 +2361,7 @@ N_("<i>\t\tskill -c wvdial\n"),
 N_("Otherwise do not append the \"&\" on more common ppp Start\n"
 	"Command entries.\n"
 	"If the timer button is not linked to a net interface, then it can\n"
-	"be used as a push on / push off timer\n\n"),
+	"be used as a push on / push off timer\n"),
 
 #endif
 
