@@ -616,7 +616,7 @@ lookup_monitor_from_name(gchar *name)
 	for (list = gkrellm_monitor_list; list; list = list->next)
 		{
 		mon = (Monitor *) list->data;
-		if (!mon->name)
+		if (!mon->name || mon->id < 0)
 			continue;
 		if (!strcmp(name, mon->name))
 			return mon;
@@ -1218,6 +1218,11 @@ place_button_sensitivity(Monitor *plugin, gboolean state)
 	{
 	Monitor	*mon = NULL;
 
+	if (gkrellm_demo_mode())
+		{
+		gtk_widget_set_sensitive(place_button, FALSE);
+		return;
+		}
 	place_plugin = plugin;
 	if (state && plugin->create_monitor)
 		{
