@@ -40,7 +40,7 @@ typedef enum
 	gl518,
 	gl520,
 	via686,
-	adm1025,
+	adm_lm,	/* includes adm1025 adm9240 lm87 lm81 ds1780 */
 	mtp008,
 	it87
 	}
@@ -190,29 +190,31 @@ static VoltDefault	voltdefault6[] =
 	{ "Vtt",	1.0,   0,       NULL }		/* in6 */
 	};
 
-	/* adm1025-*	*/
+	/* adm1025-*	adm9240-*	lm87-*	lm81-* ds1780-* */
 static VoltDefault	voltdefault7[] =
 	{
-	{ "+2.5V",	1.0,   0,       NULL },		/* in0 */
-	{ "VCCP",	1.0,   0,       NULL },		/* in1 */
-	{ "+3.3V",	1.0,   0,       NULL },		/* in2 */
-	{ "+5V",	1.0,   0,       NULL },		/* in3 */
-	{ "+12V",	1.0,   0,       NULL },		/* in4 */
-	{ "VCC",	1.0,   0,       NULL }		/* in5 */
+	{ "2.5V",	1.0,   0,       NULL },		/* in0 */
+	{ "Vccp",	1.0,   0,       NULL },		/* in1 */
+	{ "3.3V",	1.0,   0,       NULL },		/* in2 */
+	{ "5V",		1.0,   0,       NULL },		/* in3 */
+	{ "12V",	1.0,   0,       NULL },		/* in4 */
+	{ "Vcc",	1.0,   0,       NULL }		/* in5 */
 	};
 
-	/* it878-*	*/
+	/* it87-*	it8705-*	it8712	*/
 static VoltDefault	voltdefault8[] =
 	{
-	{ "Vcor1",	1.0,    0, NULL },
-	{ "Vcor2",	1.0,    0, NULL },
-	{ "+3.3V",	2.0,    0, NULL },		/* in2 (1 + 1)*@		*/
-	{ "+5V",	1.68,   0, NULL },		/* in3 ((6.8/10)+1)*@	*/
-	{ "+12V",	4.0,    0, NULL },		/* in4 ((30/10)+1)*@	*/
-	{ "-12V",	-7.2,   0, NULL },		/* in5 -(72/10)*@		*/
-	{ "-5V",	-5.6,   0, NULL },		/* in6 -(56/10)*@		*/
-	{ "Stby",	1.68,   0, NULL }		/* in7 ((6.8/10)+1)*@	*/
+	{ "Vcor1",	1.0,    0, 		NULL },
+	{ "Vcor2",	1.0,    0, 		NULL },
+	{ "+3.3V",	2.0,    0, 		NULL },		/* in2 (1 + 1)*@		*/
+	{ "+5V",	1.68,   0, 		NULL },		/* in3 ((6.8/10)+1)*@	*/
+	{ "+12V",	4.0,    0, 		NULL },		/* in4 ((30/10)+1)*@	*/
+	{ "-12V",	7.67,   -27.36, NULL },		/* in5 (7.67 * @) - 27.36 */
+	{ "-5V",	4.33,   -13.64, NULL },		/* in6 (4.33 * @) - 13.64 */
+	{ "Stby",	1.68,   0, 		NULL },		/* in7 ((6.8/10)+1)*@	*/
+	{ "Vbat",	1.0,    0, 		NULL }		/* in8					*/
 	};
+
 #endif	/* __linux__ */
 
 /* ====== System dependent interface ====================================== */
@@ -508,9 +510,14 @@ get_volt_default(gchar *chip_name, VoltDefault **vdf, gint *vdfsize,
 		*vdf = &voltdefault8[0];
 		*vdfsize = sizeof (voltdefault8) / sizeof (VoltDefault);
 		}
-	else if (!strncmp(chip_name, "adm1025", 7))
+	else if (   !strncmp(chip_name, "adm1025", 7)
+			 || !strncmp(chip_name, "adm9240", 7)
+			 || !strncmp(chip_name, "lm87", 4)
+			 || !strncmp(chip_name, "lm81", 4)
+			 || !strncmp(chip_name, "ds1780", 6)
+			)
 		{
-		*chip = adm1025;
+		*chip = adm_lm;
 		*vdf = &voltdefault7[0];
 		*vdfsize = sizeof (voltdefault7) / sizeof (VoltDefault);
 		}
@@ -2037,9 +2044,15 @@ create_sensors(GtkWidget *vbox, gint first_create)
 	create_sensors_monitor(vbox, first_create);
 	}
 
+  /* FIXME: monitor_sensors and monitor_config_sensors should be combined,
+  |  but the issue is apply_sensors_config() must be called before the CPU
+  |  and Proc apply, and I want create_sensors() called after the CPU and Proc
+  |  create.  So for now, two Monitor structs and have two sensor monitor
+  |  add_builtins() in main.c.
+  */
 static Monitor	monitor_sensors =
 	{
-	N_("sensors"),		/* Voltage config handled in Sensors tab */
+	N_("Sensors"),		/* Voltage config handled in Sensors tab */
 	MON_VOLTAGE,		/* Id,  0 if a plugin		*/
 	create_sensors,		/* The create function		*/
 	update_sensors,		/* The update function		*/
@@ -2063,6 +2076,9 @@ static Monitor	monitor_sensors =
 Monitor *
 init_sensor_monitor(void)
 	{
+	if (!sensor_list)
+		return NULL;
+	monitor_sensors.name = _(monitor_sensors.name);
 	style_id = gkrellm_add_meter_style(&monitor_sensors, SENSOR_STYLE_NAME);
 	mon_sensors = &monitor_sensors;
 	return &monitor_sensors;
@@ -2436,7 +2452,7 @@ cb_sensor_set_alert(GtkWidget *entry, Sensor *s)
 
 static gchar	*sensor_info_text0[]	= 
 	{
-N_("<b>\nSetup\n"),
+N_("<b>Setup\n"),
 N_("For temperature or fan sensors, enter a label on the Setup page next to\n"
 "a Sensor File to display it. The display will appear on a CPU or Proc panel\n"
 "if you use reserved name labels which are (lower case):\n")
